[![Code Health](https://landscape.io/github/labrosse/dmsuite/master/landscape.svg?style=flat)](https://landscape.io/github/labrosse/dmsuite/master)
# dmsuite
A collection of spectral collocation differentiation matrices

This collection is based on their original matlab/octave version
developed by Weidemann and Reddy and available from
[DMSUITE](http://www.mathworks.com/matlabcentral/fileexchange/29-dmsuite). The
theory and examples are explained in their paper:
J. A. C. Weidemann and S. C. Reddy, A MATLAB Differentiation Matrix
Suite, ACM Transactions on Mathematical Software, 26, (2000) :
465-519.

The port to python was initiated as part of a larger project by
ronojoy as https://github.com/ronojoy/pyddx.git
